Contributors
============

    1. Prof. Aldo H. Romero [West Virginia University] (Project Director)
    2. Guillermo Avendaño-Franco [West Virginia University] (Basic Infraestructure)
    3. Adam Payne [West Virginia University] (Bug Fixes)
    4. Irais Valencia Jaime [West Virginia University] (Simulation and testing)
    5. Sobhit Singh [West Virginia University] (Data-mining)
    6. Francisco Muñoz (Universidad de Chile) (pyprocar)
